==> nifi-2.2.0-source-release.zip: nifi-2.2.0/nifi-frontend/src/main/frontend/libs/shared/src/components/index.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export * from './close-on-escape-dialog/close-on-escape-dialog.component';
export * from './component-context/component-context.component';
export * from './map-table/map-table.component';
export * from './copy-button/copy-button.component';
export * from './new-map-table-entry-dialog/new-map-table-entry-dialog.component';
export * from './property-hint/property-hint.component';
export * from './resizable/resizable.component';
export * from './yes-no-dialog/yes-no-dialog.component';
export * from './tooltips/el-function-tip/el-function-tip.component';
export * from './tooltips/parameter-tip/parameter-tip.component';
export * from './tooltips/property-hint-tip/property-hint-tip.component';
export * from './tooltips/text-tip/text-tip.component';

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-frontend/src/main/frontend/libs/shared/src/components/index.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export * from './close-on-escape-dialog/close-on-escape-dialog.component';
export * from './component-context/component-context.component';
export * from './map-table/map-table.component';
export * from './copy-button/copy-button.component';
export * from './new-map-table-entry-dialog/new-map-table-entry-dialog.component';
export * from './property-hint/property-hint.component';
export * from './resizable/resizable.component';
export * from './codemirror/codemirror.component';
export * from './codemirror/themes/defaultTheme';
export * from './codemirror/themes/baseTheme';
export * from './yes-no-dialog/yes-no-dialog.component';
export * from './tooltips/property-hint-tip/property-hint-tip.component';
export * from './tooltips/text-tip/text-tip.component';
